# coding: utf-8

"""
    Nucleus API

    BETA version of the nucleus text analytics API. Example and documentation: https://github.com/SumUpAnalytics/nucleus-sdk  # noqa: E501

    OpenAPI spec version: v0.1.7
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401
import time

# python 2 and python 3 compatibility library
import six
import numpy as np
import matplotlib.pyplot as plt

import nucleus_api
from nucleus_api.api_client import ApiClient
from nucleus_api.rest import ApiException

###############################################################################
# Helpfer functions
###############################################################################
#
# Summariize a file from URL
# * Create a temporary dataset
# * Run document summary API to generate the summary
# * Delete the temporary dataset
#
# file_params fields descriptions:
#   file_url              : string, the URL at which the file is stored (could be a S3 bucket address for instance)
#   filename              : OPTIONAL string, filename saved on the server. also serves as the doc_title for summarization
#   custom_stop_words     : OPTIONAL a string list, user-provided list of stopwords to be excluded from the content analysis leading to document summarization
#                            ["word1", "word2", ...]. DEFAULT: empty
#   summary_length        : OPTIONAL an integer, the maximum number of bullet points a user wants to see in the document summary. DEFAULT: 6
#   context_amount        : OPTIONAL an integer, the number of sentences surrounding key summary sentences in the original document that a user wants to see in the document summary. DEFAULT: 0
#   short_sentence_length : OPTIONAL an integer, the sentence length below which a sentence is excluded from summarization. DEFAULT: 4 words
#   long_sentence_length  : OPTIONAL an integer, the sentence length beyond which a sentence is excluded from summarization. DEFAULT: 40 words
#
def summarize_file_url(api_instance, file_params):
    dataset = 'test0'   # to be deleted
    
    ############################################################################
    # create the dataset with URL
    payload = nucleus_api.UploadURLModel(
                dataset=dataset,
                file_url=file_params['file_url'],
                filename=file_params['filename']
            ) # UploadURLModel | 

    try:
        api_response = api_instance.post_upload_url(payload)
        #print(api_response)   # raw API response
    except ApiException as e:
        print("Exception when calling DatasetsApi->post_upload_url: %s\n" % e)
    
    
    ################################################################################
    # Get document summary
    try:
        api_response = api_instance.get_doc_summary_api(
            dataset=dataset,
            doc_title=file_params['filename'],
            #custom_stop_words=custom_stop_words, 
            summary_length=file_params['summary_length'],
            context_amount=file_params['context_amount'],
            short_sentence_length=file_params['short_sentence_length'],
            long_sentence_length=file_params['long_sentence_length'])
    
        doc_summary_api_result = api_response.result
    
    except ApiException as e:
        print("Exception when calling DocumentsApi->get_doc_summary_api: %s\n" % e)

    #################################################################################
    # delete the dataset
    payload = nucleus_api.Deletedatasetmodel(dataset=dataset) # Deletedatasetmodel | 

    try:
        api_response = api_instance.post_delete_dataset(payload)
        #pprint(api_response)
    except ApiException as e:
        print("Exception when calling DatasetsApi->post_delete_dataset: %s\n" % e)

    return doc_summary_api_result

#
# Plot topic historical analysis
#
def topic_charts_historical(historical_metrics, selected_topics, show_sentiment_consensus):

    # Charts of Strength, Sentiment, Consensus for each of the topics
    current_max_strength = 0
    current_max_sent = 0
    current_max_cons = 0
    for i in selected_topics:
        if np.nanmax(np.abs(historical_metrics[i]['strength'])) > current_max_strength:
            current_max_strength = np.nanmax(np.abs(historical_metrics[i]['strength']))
        if np.nanmax(np.abs(historical_metrics[i]['sentiment'])) > current_max_sent:
            current_max_sent = np.nanmax(np.abs(historical_metrics[i]['sentiment']))
        if np.nanmax(np.abs(historical_metrics[i]['consensus'])) > current_max_cons:
            current_max_cons = np.nanmax(np.abs(historical_metrics[i]['consensus']))

    if show_sentiment_consensus == True:
        plt.rcParams['figure.figsize'] = [12, 18*len(selected_topics)]
        fig = plt.figure() 
        for i in selected_topics:
            current_ax = 'ax' + str(selected_topics.index(i) + 1)
            if current_ax == 'ax1':
                current_ax = plt.subplot(3*len(selected_topics), 1, 1 + 3*selected_topics.index(i))
                ax1 = plt.subplot(3*len(selected_topics), 1, 1 + 3*selected_topics.index(i))
            else:
                current_ax = plt.subplot(3*len(selected_topics), 1, 1 + 3*selected_topics.index(i), sharex=ax1)

            # 3 subplots, one per strength, sentiment, consensus
            current_ax.set_ylim([0, 1.05*current_max_strength])
            current_ax.plot('time_stamps', 'strength', data=historical_metrics[i], color='blue')
            plt.ylabel('Prevalence', fontsize=14, fontweight="bold")
            plt.title(historical_metrics[i]['topic'], fontsize=14, fontweight="bold")

            current_axSent = plt.subplot(3*len(selected_topics), 1, 1 + 3*selected_topics.index(i) + 1, sharex=ax1)
            current_axSent.set_ylim([-1.05*current_max_sent, 1.05*current_max_sent])
            current_axSent.plot('time_stamps', 'sentiment', data=historical_metrics[i], color='green')
            plt.ylabel('Sentiment', fontsize=14, fontweight="bold")

            current_axCons = plt.subplot(3*len(selected_topics), 1, 1 + 3*selected_topics.index(i) + 2, sharex=ax1)
            current_axCons.set_ylim([0, 1.05*current_max_cons])
            current_axCons.plot('time_stamps', 'consensus', data=historical_metrics[i], color='red')
            plt.ylabel('Consensus', fontsize=14, fontweight="bold")

        fig.autofmt_xdate(rotation=90)
    else:
        plt.rcParams['figure.figsize'] = [12, 6*len(selected_topics)]
        fig = plt.figure()
        for i in selected_topics:
            current_ax = 'ax' + str(selected_topics.index(i) + 1)
            if current_ax == 'ax1':
                current_ax = plt.subplot(len(selected_topics), 1, selected_topics.index(i) + 1)
                ax1 = plt.subplot(len(selected_topics), 1, selected_topics.index(i) + 1)
            else:
                current_ax = plt.subplot(len(selected_topics), 1, selected_topics.index(i) + 1, sharex=ax1)
            current_ax.set_ylim([0, 1.05*current_max_strength])
            current_ax.plot('time_stamps', 'strength', data=historical_metrics[i], color='blue')
            plt.ylabel('Prevalence', fontsize=14, fontweight="bold")        
            plt.title(historical_metrics[i]['topic'], fontsize=14, fontweight="bold")
        fig.autofmt_xdate(rotation=90)
        
    return 0

################################################################################
# templates
################################################################################
class NucleusApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_author_connectivity_api(self, dataset, target_author, **kwargs):  # noqa: E501
        """get_author_connectivity_api  # noqa: E501

        Get the network of similar authors to a reference author.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_author_connectivity_api(dataset, target_author, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset: Dataset name. (required)
        :param str target_author: Name of the author to be analyzed. (required)
        :param str query: Fulltext query, using mysql MATCH boolean query format. Subject covered by the author, on which to focus the analysis of connectivity. Example, (\"word1\" OR \"word2\") AND (\"word3\" OR \"word4\")
        :param str custom_stop_words: List of words possibly used by the target author that are considered not information-bearing.
        :param str time_period: Alternative 1: Time period selection
        :param str period_start: Alternative 2: Start date for the period to analyze within the dataset. Format: \"YYYY-MM-DD HH:MM:SS\" 
        :param str period_end: Alternative 2: End date for the period to analyze within the dataset. Format: \"YYYY-MM-DD HH:MM:SS\" 
        :param str metadata_selection: json object of {\"metadata_field\":[\"selected_values\"]}
        :param str excluded_docs: List of document IDs that should be excluded from the analysis. Example, \"docid1, docid2, ..., docidN\" 
        :return: AuthorConnectRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_author_connectivity_api_with_http_info(dataset, target_author, **kwargs)  # noqa: E501
        else:
            (data) = self.get_author_connectivity_api_with_http_info(dataset, target_author, **kwargs)  # noqa: E501
            return data

    def get_author_connectivity_api_with_http_info(self, dataset, target_author, **kwargs):  # noqa: E501
        """get_author_connectivity_api  # noqa: E501

        Get the network of similar authors to a reference author.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_author_connectivity_api_with_http_info(dataset, target_author, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset: Dataset name. (required)
        :param str target_author: Name of the author to be analyzed. (required)
        :param str query: Fulltext query, using mysql MATCH boolean query format. Subject covered by the author, on which to focus the analysis of connectivity. Example, (\"word1\" OR \"word2\") AND (\"word3\" OR \"word4\")
        :param str custom_stop_words: List of words possibly used by the target author that are considered not information-bearing.
        :param str time_period: Alternative 1: Time period selection
        :param str period_start: Alternative 2: Start date for the period to analyze within the dataset. Format: \"YYYY-MM-DD HH:MM:SS\" 
        :param str period_end: Alternative 2: End date for the period to analyze within the dataset. Format: \"YYYY-MM-DD HH:MM:SS\" 
        :param str metadata_selection: json object of {\"metadata_field\":[\"selected_values\"]}
        :param str excluded_docs: List of document IDs that should be excluded from the analysis. Example, \"docid1, docid2, ..., docidN\" 
        :return: AuthorConnectRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['dataset', 'target_author', 'query', 'custom_stop_words', 'time_period', 'period_start', 'period_end', 'metadata_selection', 'excluded_docs']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_author_connectivity_api" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'dataset' is set
        if ('dataset' not in params or
                params['dataset'] is None):
            raise ValueError("Missing the required parameter `dataset` when calling `get_author_connectivity_api`")  # noqa: E501
        # verify the required parameter 'target_author' is set
        if ('target_author' not in params or
                params['target_author'] is None):
            raise ValueError("Missing the required parameter `target_author` when calling `get_author_connectivity_api`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'dataset' in params:
            query_params.append(('dataset', params['dataset']))  # noqa: E501
        if 'target_author' in params:
            query_params.append(('target_author', params['target_author']))  # noqa: E501
        if 'query' in params:
            query_params.append(('query', params['query']))  # noqa: E501
        if 'custom_stop_words' in params:
            query_params.append(('custom_stop_words', params['custom_stop_words']))  # noqa: E501
        if 'time_period' in params:
            query_params.append(('time_period', params['time_period']))  # noqa: E501
        if 'period_start' in params:
            query_params.append(('period_start', params['period_start']))  # noqa: E501
        if 'period_end' in params:
            query_params.append(('period_end', params['period_end']))  # noqa: E501
        if 'metadata_selection' in params:
            query_params.append(('metadata_selection', params['metadata_selection']))  # noqa: E501
        if 'excluded_docs' in params:
            query_params.append(('excluded_docs', params['excluded_docs']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/html'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikey']  # noqa: E501

        response_type='AuthorConnectRespModel'  # noqa: E501
        res = self.api_client.call_api(
            '/topics/author_connectivity', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

        #print('call-api res=', res)
        if res.job_id == None:
            pass
            #print('pass get_job.res=', res)
        else:
            #print('start polling...')
            i = 0
            job_id = res.job_id
            while res.result == None:
                time.sleep(1)
                res = self.get_job(job_id)
                #print('get_job.res=', res)
                if res.error != None:
                    print('Error:', res.error)
                    break

                i += 1
                if i > 7200:
                    print('Error: API timed out')
                    break
    
                if i % 60 == 0:
                    print('The job has been running for', i/60, 'minutes')
                #print('sleeping...', i)
            
            # poll completed. convert response to the actual API response type
            #print('response_type=', response_type)
            if response_type != 'JobRespModel':
                #print('res.result before poll', type(res.result), res.result)

                if isinstance(res.result, str):
                    result = res.result
                else:
                    result = res.result.to_str()
                     
                
                #print('res before conversion', result)
                res = self.api_client.deserialize_result(result, response_type)
                #print('res after conversion', type(res), res)

        return res


    def get_dataset_info(self, dataset, **kwargs):  # noqa: E501
        """get_dataset_info  # noqa: E501

        Get information about a dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_dataset_info(dataset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset: Dataset name. (required)
        :param str query: Fulltext query, using mysql MATCH boolean query format.
        :param str metadata_selection: json object of {\"metadata_field\":[\"selected_values\"]}
        :param str time_period: Time period selection
        :return: DatasetInfoRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_dataset_info_with_http_info(dataset, **kwargs)  # noqa: E501
        else:
            (data) = self.get_dataset_info_with_http_info(dataset, **kwargs)  # noqa: E501
            return data

    def get_dataset_info_with_http_info(self, dataset, **kwargs):  # noqa: E501
        """get_dataset_info  # noqa: E501

        Get information about a dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_dataset_info_with_http_info(dataset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset: Dataset name. (required)
        :param str query: Fulltext query, using mysql MATCH boolean query format.
        :param str metadata_selection: json object of {\"metadata_field\":[\"selected_values\"]}
        :param str time_period: Time period selection
        :return: DatasetInfoRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['dataset', 'query', 'metadata_selection', 'time_period']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_dataset_info" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'dataset' is set
        if ('dataset' not in params or
                params['dataset'] is None):
            raise ValueError("Missing the required parameter `dataset` when calling `get_dataset_info`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'dataset' in params:
            query_params.append(('dataset', params['dataset']))  # noqa: E501
        if 'query' in params:
            query_params.append(('query', params['query']))  # noqa: E501
        if 'metadata_selection' in params:
            query_params.append(('metadata_selection', params['metadata_selection']))  # noqa: E501
        if 'time_period' in params:
            query_params.append(('time_period', params['time_period']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/html'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikey']  # noqa: E501

        response_type='DatasetInfoRespModel'  # noqa: E501
        res = self.api_client.call_api(
            '/datasets/dataset_info', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

        #print('call-api res=', res)
        if res.job_id == None:
            pass
            #print('pass get_job.res=', res)
        else:
            #print('start polling...')
            i = 0
            job_id = res.job_id
            while res.result == None:
                time.sleep(1)
                res = self.get_job(job_id)
                #print('get_job.res=', res)
                if res.error != None:
                    print('Error:', res.error)
                    break

                i += 1
                if i > 7200:
                    print('Error: API timed out')
                    break
    
                if i % 60 == 0:
                    print('The job has been running for', i/60, 'minutes')
                #print('sleeping...', i)
            
            # poll completed. convert response to the actual API response type
            #print('response_type=', response_type)
            if response_type != 'JobRespModel':
                #print('res.result before poll', type(res.result), res.result)

                if isinstance(res.result, str):
                    result = res.result
                else:
                    result = res.result.to_str()
                     
                
                #print('res before conversion', result)
                res = self.api_client.deserialize_result(result, response_type)
                #print('res after conversion', type(res), res)

        return res


    def get_doc_display(self, dataset, **kwargs):  # noqa: E501
        """get_doc_display  # noqa: E501

        Document display.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_doc_display(dataset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset: Dataset name. (required)
        :param str doc_titles: The title of the documents on which info is requested. Example: [ \"title 1\", \"title 2\" ] 
        :param str doc_ids: The docid of the documents on which info is requested. Example:[ \"docid1, docid2\" ]
        :return: DocDisplayRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_doc_display_with_http_info(dataset, **kwargs)  # noqa: E501
        else:
            (data) = self.get_doc_display_with_http_info(dataset, **kwargs)  # noqa: E501
            return data

    def get_doc_display_with_http_info(self, dataset, **kwargs):  # noqa: E501
        """get_doc_display  # noqa: E501

        Document display.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_doc_display_with_http_info(dataset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset: Dataset name. (required)
        :param str doc_titles: The title of the documents on which info is requested. Example: [ \"title 1\", \"title 2\" ] 
        :param str doc_ids: The docid of the documents on which info is requested. Example:[ \"docid1, docid2\" ]
        :return: DocDisplayRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['dataset', 'doc_titles', 'doc_ids']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_doc_display" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'dataset' is set
        if ('dataset' not in params or
                params['dataset'] is None):
            raise ValueError("Missing the required parameter `dataset` when calling `get_doc_display`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'dataset' in params:
            query_params.append(('dataset', params['dataset']))  # noqa: E501
        if 'doc_titles' in params:
            query_params.append(('doc_titles', params['doc_titles']))  # noqa: E501
        if 'doc_ids' in params:
            query_params.append(('doc_ids', params['doc_ids']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/html'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikey']  # noqa: E501

        response_type='DocDisplayRespModel'  # noqa: E501
        res = self.api_client.call_api(
            '/documents/document_display', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

        #print('call-api res=', res)
        if res.job_id == None:
            pass
            #print('pass get_job.res=', res)
        else:
            #print('start polling...')
            i = 0
            job_id = res.job_id
            while res.result == None:
                time.sleep(1)
                res = self.get_job(job_id)
                #print('get_job.res=', res)
                if res.error != None:
                    print('Error:', res.error)
                    break

                i += 1
                if i > 7200:
                    print('Error: API timed out')
                    break
    
                if i % 60 == 0:
                    print('The job has been running for', i/60, 'minutes')
                #print('sleeping...', i)
            
            # poll completed. convert response to the actual API response type
            #print('response_type=', response_type)
            if response_type != 'JobRespModel':
                #print('res.result before poll', type(res.result), res.result)

                if isinstance(res.result, str):
                    result = res.result
                else:
                    result = res.result.to_str()
                     
                
                #print('res before conversion', result)
                res = self.api_client.deserialize_result(result, response_type)
                #print('res after conversion', type(res), res)

        return res


    def get_doc_info(self, dataset, **kwargs):  # noqa: E501
        """get_doc_info  # noqa: E501

        Document metadata retrieval.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_doc_info(dataset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset: Dataset name. (required)
        :param str doc_titles: The title of the documents on which info is requested. Example: [ \"title 1\", \"title 2\" ] 
        :param str doc_ids: The docid of the documents on which info is requested. Example:[ \"docid1, docid2\" ]
        :return: DocInfoRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_doc_info_with_http_info(dataset, **kwargs)  # noqa: E501
        else:
            (data) = self.get_doc_info_with_http_info(dataset, **kwargs)  # noqa: E501
            return data

    def get_doc_info_with_http_info(self, dataset, **kwargs):  # noqa: E501
        """get_doc_info  # noqa: E501

        Document metadata retrieval.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_doc_info_with_http_info(dataset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset: Dataset name. (required)
        :param str doc_titles: The title of the documents on which info is requested. Example: [ \"title 1\", \"title 2\" ] 
        :param str doc_ids: The docid of the documents on which info is requested. Example:[ \"docid1, docid2\" ]
        :return: DocInfoRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['dataset', 'doc_titles', 'doc_ids']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_doc_info" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'dataset' is set
        if ('dataset' not in params or
                params['dataset'] is None):
            raise ValueError("Missing the required parameter `dataset` when calling `get_doc_info`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'dataset' in params:
            query_params.append(('dataset', params['dataset']))  # noqa: E501
        if 'doc_titles' in params:
            query_params.append(('doc_titles', params['doc_titles']))  # noqa: E501
        if 'doc_ids' in params:
            query_params.append(('doc_ids', params['doc_ids']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/html'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikey']  # noqa: E501

        response_type='DocInfoRespModel'  # noqa: E501
        res = self.api_client.call_api(
            '/documents/document_info', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

        #print('call-api res=', res)
        if res.job_id == None:
            pass
            #print('pass get_job.res=', res)
        else:
            #print('start polling...')
            i = 0
            job_id = res.job_id
            while res.result == None:
                time.sleep(1)
                res = self.get_job(job_id)
                #print('get_job.res=', res)
                if res.error != None:
                    print('Error:', res.error)
                    break

                i += 1
                if i > 7200:
                    print('Error: API timed out')
                    break
    
                if i % 60 == 0:
                    print('The job has been running for', i/60, 'minutes')
                #print('sleeping...', i)
            
            # poll completed. convert response to the actual API response type
            #print('response_type=', response_type)
            if response_type != 'JobRespModel':
                #print('res.result before poll', type(res.result), res.result)

                if isinstance(res.result, str):
                    result = res.result
                else:
                    result = res.result.to_str()
                     
                
                #print('res before conversion', result)
                res = self.api_client.deserialize_result(result, response_type)
                #print('res after conversion', type(res), res)

        return res


    def get_doc_recommend_api(self, dataset, **kwargs):  # noqa: E501
        """get_doc_recommend_api  # noqa: E501

        Recommendation of documents on given topics that have been extracted from a given dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_doc_recommend_api(dataset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset: Dataset name. (required)
        :param str query: Fulltext query, using mysql MATCH boolean query format. Example, (\"word1\" OR \"word2\") AND (\"word3\" OR \"word4\")
        :param str custom_stop_words: List of stop words.
        :param int num_topics: Number of topics to be extracted from the dataset.
        :param int num_keywords: Number of keywords per topic that is extracted from the dataset.
        :param int num_docs: Number of desired recommended docs per topic.
        :param str metadata_selection: json object of {\"metadata_field\":[\"selected_values\"]}
        :param str time_period: Time period selection
        :param str excluded_docs: List of document IDs that should be excluded from the analysis. Example, \"docid1, docid2, ..., docidN\" 
        :return: DocumentRecommendRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_doc_recommend_api_with_http_info(dataset, **kwargs)  # noqa: E501
        else:
            (data) = self.get_doc_recommend_api_with_http_info(dataset, **kwargs)  # noqa: E501
            return data

    def get_doc_recommend_api_with_http_info(self, dataset, **kwargs):  # noqa: E501
        """get_doc_recommend_api  # noqa: E501

        Recommendation of documents on given topics that have been extracted from a given dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_doc_recommend_api_with_http_info(dataset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset: Dataset name. (required)
        :param str query: Fulltext query, using mysql MATCH boolean query format. Example, (\"word1\" OR \"word2\") AND (\"word3\" OR \"word4\")
        :param str custom_stop_words: List of stop words.
        :param int num_topics: Number of topics to be extracted from the dataset.
        :param int num_keywords: Number of keywords per topic that is extracted from the dataset.
        :param int num_docs: Number of desired recommended docs per topic.
        :param str metadata_selection: json object of {\"metadata_field\":[\"selected_values\"]}
        :param str time_period: Time period selection
        :param str excluded_docs: List of document IDs that should be excluded from the analysis. Example, \"docid1, docid2, ..., docidN\" 
        :return: DocumentRecommendRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['dataset', 'query', 'custom_stop_words', 'num_topics', 'num_keywords', 'num_docs', 'metadata_selection', 'time_period', 'excluded_docs']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_doc_recommend_api" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'dataset' is set
        if ('dataset' not in params or
                params['dataset'] is None):
            raise ValueError("Missing the required parameter `dataset` when calling `get_doc_recommend_api`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'dataset' in params:
            query_params.append(('dataset', params['dataset']))  # noqa: E501
        if 'query' in params:
            query_params.append(('query', params['query']))  # noqa: E501
        if 'custom_stop_words' in params:
            query_params.append(('custom_stop_words', params['custom_stop_words']))  # noqa: E501
        if 'num_topics' in params:
            query_params.append(('num_topics', params['num_topics']))  # noqa: E501
        if 'num_keywords' in params:
            query_params.append(('num_keywords', params['num_keywords']))  # noqa: E501
        if 'num_docs' in params:
            query_params.append(('num_docs', params['num_docs']))  # noqa: E501
        if 'metadata_selection' in params:
            query_params.append(('metadata_selection', params['metadata_selection']))  # noqa: E501
        if 'time_period' in params:
            query_params.append(('time_period', params['time_period']))  # noqa: E501
        if 'excluded_docs' in params:
            query_params.append(('excluded_docs', params['excluded_docs']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/html'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikey']  # noqa: E501

        response_type='DocumentRecommendRespModel'  # noqa: E501
        res = self.api_client.call_api(
            '/documents/document_recommend', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

        #print('call-api res=', res)
        if res.job_id == None:
            pass
            #print('pass get_job.res=', res)
        else:
            #print('start polling...')
            i = 0
            job_id = res.job_id
            while res.result == None:
                time.sleep(1)
                res = self.get_job(job_id)
                #print('get_job.res=', res)
                if res.error != None:
                    print('Error:', res.error)
                    break

                i += 1
                if i > 7200:
                    print('Error: API timed out')
                    break
    
                if i % 60 == 0:
                    print('The job has been running for', i/60, 'minutes')
                #print('sleeping...', i)
            
            # poll completed. convert response to the actual API response type
            #print('response_type=', response_type)
            if response_type != 'JobRespModel':
                #print('res.result before poll', type(res.result), res.result)

                if isinstance(res.result, str):
                    result = res.result
                else:
                    result = res.result.to_str()
                     
                
                #print('res before conversion', result)
                res = self.api_client.deserialize_result(result, response_type)
                #print('res after conversion', type(res), res)

        return res


    def get_doc_summary_api(self, dataset, doc_title, **kwargs):  # noqa: E501
        """get_doc_summary_api  # noqa: E501

        Document summarization.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_doc_summary_api(dataset, doc_title, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset: Dataset name. (required)
        :param str doc_title: The title of the document to be summarized. (required)
        :param str custom_stop_words: List of stop words
        :param int summary_length: The maximum number of bullet points a user wants to see in the document summary.
        :param int context_amount: The number of sentences surrounding key summary sentences in the documents that they come from.
        :param int short_sentence_length: The sentence length below which a sentence is excluded from summarization
        :param int long_sentence_length: The sentence length beyond which a sentence is excluded from summarization
        :return: DocumentSummaryRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_doc_summary_api_with_http_info(dataset, doc_title, **kwargs)  # noqa: E501
        else:
            (data) = self.get_doc_summary_api_with_http_info(dataset, doc_title, **kwargs)  # noqa: E501
            return data

    def get_doc_summary_api_with_http_info(self, dataset, doc_title, **kwargs):  # noqa: E501
        """get_doc_summary_api  # noqa: E501

        Document summarization.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_doc_summary_api_with_http_info(dataset, doc_title, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset: Dataset name. (required)
        :param str doc_title: The title of the document to be summarized. (required)
        :param str custom_stop_words: List of stop words
        :param int summary_length: The maximum number of bullet points a user wants to see in the document summary.
        :param int context_amount: The number of sentences surrounding key summary sentences in the documents that they come from.
        :param int short_sentence_length: The sentence length below which a sentence is excluded from summarization
        :param int long_sentence_length: The sentence length beyond which a sentence is excluded from summarization
        :return: DocumentSummaryRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['dataset', 'doc_title', 'custom_stop_words', 'summary_length', 'context_amount', 'short_sentence_length', 'long_sentence_length']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_doc_summary_api" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'dataset' is set
        if ('dataset' not in params or
                params['dataset'] is None):
            raise ValueError("Missing the required parameter `dataset` when calling `get_doc_summary_api`")  # noqa: E501
        # verify the required parameter 'doc_title' is set
        if ('doc_title' not in params or
                params['doc_title'] is None):
            raise ValueError("Missing the required parameter `doc_title` when calling `get_doc_summary_api`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'dataset' in params:
            query_params.append(('dataset', params['dataset']))  # noqa: E501
        if 'custom_stop_words' in params:
            query_params.append(('custom_stop_words', params['custom_stop_words']))  # noqa: E501
        if 'doc_title' in params:
            query_params.append(('doc_title', params['doc_title']))  # noqa: E501
        if 'summary_length' in params:
            query_params.append(('summary_length', params['summary_length']))  # noqa: E501
        if 'context_amount' in params:
            query_params.append(('context_amount', params['context_amount']))  # noqa: E501
        if 'short_sentence_length' in params:
            query_params.append(('short_sentence_length', params['short_sentence_length']))  # noqa: E501
        if 'long_sentence_length' in params:
            query_params.append(('long_sentence_length', params['long_sentence_length']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/html'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikey']  # noqa: E501

        response_type='DocumentSummaryRespModel'  # noqa: E501
        res = self.api_client.call_api(
            '/documents/document_summary', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

        #print('call-api res=', res)
        if res.job_id == None:
            pass
            #print('pass get_job.res=', res)
        else:
            #print('start polling...')
            i = 0
            job_id = res.job_id
            while res.result == None:
                time.sleep(1)
                res = self.get_job(job_id)
                #print('get_job.res=', res)
                if res.error != None:
                    print('Error:', res.error)
                    break

                i += 1
                if i > 7200:
                    print('Error: API timed out')
                    break
    
                if i % 60 == 0:
                    print('The job has been running for', i/60, 'minutes')
                #print('sleeping...', i)
            
            # poll completed. convert response to the actual API response type
            #print('response_type=', response_type)
            if response_type != 'JobRespModel':
                #print('res.result before poll', type(res.result), res.result)

                if isinstance(res.result, str):
                    result = res.result
                else:
                    result = res.result.to_str()
                     
                
                #print('res before conversion', result)
                res = self.api_client.deserialize_result(result, response_type)
                #print('res after conversion', type(res), res)

        return res


    def get_job(self, id, **kwargs):  # noqa: E501
        """get_job  # noqa: E501

        Use this API to check the progress and retrieve results of a job. Poll this endpoint repeatedly until result is not null.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_job(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of the job (required)
        :return: JobRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_job_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_job_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_job_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_job  # noqa: E501

        Use this API to check the progress and retrieve results of a job. Poll this endpoint repeatedly until result is not null.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_job_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of the job (required)
        :return: JobRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'id' in params:
            query_params.append(('id', params['id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/html'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikey']  # noqa: E501

        response_type='JobRespModel'  # noqa: E501
        res = self.api_client.call_api(
            '/jobs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

        #print('call-api res=', res)
        if res.job_id == None:
            pass
            #print('pass get_job.res=', res)
        else:
            #print('start polling...')
            i = 0
            job_id = res.job_id
            while res.result == None:
                time.sleep(1)
                res = self.get_job(job_id)
                #print('get_job.res=', res)
                if res.error != None:
                    print('Error:', res.error)
                    break

                i += 1
                if i > 7200:
                    print('Error: API timed out')
                    break
    
                if i % 60 == 0:
                    print('The job has been running for', i/60, 'minutes')
                #print('sleeping...', i)
            
            # poll completed. convert response to the actual API response type
            #print('response_type=', response_type)
            if response_type != 'JobRespModel':
                #print('res.result before poll', type(res.result), res.result)

                if isinstance(res.result, str):
                    result = res.result
                else:
                    result = res.result.to_str()
                     
                
                #print('res before conversion', result)
                res = self.api_client.deserialize_result(result, response_type)
                #print('res after conversion', type(res), res)

        return res


    def get_list_datasets(self, **kwargs):  # noqa: E501
        """get_list_datasets  # noqa: E501

        List the datasets owned by the user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_list_datasets(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ListDatasetsModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_list_datasets_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_list_datasets_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_list_datasets_with_http_info(self, **kwargs):  # noqa: E501
        """get_list_datasets  # noqa: E501

        List the datasets owned by the user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_list_datasets_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ListDatasetsModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_list_datasets" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/html'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikey']  # noqa: E501

        response_type='ListDatasetsModel'  # noqa: E501
        res = self.api_client.call_api(
            '/datasets', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

        #print('call-api res=', res)
        if res.job_id == None:
            pass
            #print('pass get_job.res=', res)
        else:
            #print('start polling...')
            i = 0
            job_id = res.job_id
            while res.result == None:
                time.sleep(1)
                res = self.get_job(job_id)
                #print('get_job.res=', res)
                if res.error != None:
                    print('Error:', res.error)
                    break

                i += 1
                if i > 7200:
                    print('Error: API timed out')
                    break
    
                if i % 60 == 0:
                    print('The job has been running for', i/60, 'minutes')
                #print('sleeping...', i)
            
            # poll completed. convert response to the actual API response type
            #print('response_type=', response_type)
            if response_type != 'JobRespModel':
                #print('res.result before poll', type(res.result), res.result)

                if isinstance(res.result, str):
                    result = res.result
                else:
                    result = res.result.to_str()
                     
                
                #print('res before conversion', result)
                res = self.api_client.deserialize_result(result, response_type)
                #print('res after conversion', type(res), res)

        return res


    def get_topic_api(self, dataset, **kwargs):  # noqa: E501
        """get_topic_api  # noqa: E501

        Get key topics from a given dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_topic_api(dataset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset: Dataset name. (required)
        :param str query: Fulltext query, using mysql MATCH boolean query format. Example, (\"word1\" OR \"word2\") AND (\"word3\" OR \"word4\")
        :param str custom_stop_words: List of stop words.
        :param int num_topics: Number of topics to be extracted from the dataset.
        :param int num_keywords: Number of keywords per topic that is extracted from the dataset.
        :param str metadata_selection: json object of {\"metadata_field\":[\"selected_values\"]}
        :param str time_period: Alternative 1: Time period selection
        :param str period_start: Alternative 2: Start date for the period to analyze within the dataset. Format: \"YYYY-MM-DD HH:MM:SS\" 
        :param str period_end: Alternative 2: End date for the period to analyze within the dataset. Format: \"YYYY-MM-DD HH:MM:SS\" 
        :param str excluded_docs: List of document IDs that should be excluded from the analysis. Example, \"docid1, docid2, ..., docidN\" 
        :return: TopicRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_topic_api_with_http_info(dataset, **kwargs)  # noqa: E501
        else:
            (data) = self.get_topic_api_with_http_info(dataset, **kwargs)  # noqa: E501
            return data

    def get_topic_api_with_http_info(self, dataset, **kwargs):  # noqa: E501
        """get_topic_api  # noqa: E501

        Get key topics from a given dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_topic_api_with_http_info(dataset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset: Dataset name. (required)
        :param str query: Fulltext query, using mysql MATCH boolean query format. Example, (\"word1\" OR \"word2\") AND (\"word3\" OR \"word4\")
        :param str custom_stop_words: List of stop words.
        :param int num_topics: Number of topics to be extracted from the dataset.
        :param int num_keywords: Number of keywords per topic that is extracted from the dataset.
        :param str metadata_selection: json object of {\"metadata_field\":[\"selected_values\"]}
        :param str time_period: Alternative 1: Time period selection
        :param str period_start: Alternative 2: Start date for the period to analyze within the dataset. Format: \"YYYY-MM-DD HH:MM:SS\" 
        :param str period_end: Alternative 2: End date for the period to analyze within the dataset. Format: \"YYYY-MM-DD HH:MM:SS\" 
        :param str excluded_docs: List of document IDs that should be excluded from the analysis. Example, \"docid1, docid2, ..., docidN\" 
        :return: TopicRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['dataset', 'query', 'custom_stop_words', 'num_topics', 'num_keywords', 'metadata_selection', 'time_period', 'period_start', 'period_end', 'excluded_docs']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_topic_api" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'dataset' is set
        if ('dataset' not in params or
                params['dataset'] is None):
            raise ValueError("Missing the required parameter `dataset` when calling `get_topic_api`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'dataset' in params:
            query_params.append(('dataset', params['dataset']))  # noqa: E501
        if 'query' in params:
            query_params.append(('query', params['query']))  # noqa: E501
        if 'custom_stop_words' in params:
            query_params.append(('custom_stop_words', params['custom_stop_words']))  # noqa: E501
        if 'num_topics' in params:
            query_params.append(('num_topics', params['num_topics']))  # noqa: E501
        if 'num_keywords' in params:
            query_params.append(('num_keywords', params['num_keywords']))  # noqa: E501
        if 'metadata_selection' in params:
            query_params.append(('metadata_selection', params['metadata_selection']))  # noqa: E501
        if 'time_period' in params:
            query_params.append(('time_period', params['time_period']))  # noqa: E501
        if 'period_start' in params:
            query_params.append(('period_start', params['period_start']))  # noqa: E501
        if 'period_end' in params:
            query_params.append(('period_end', params['period_end']))  # noqa: E501
        if 'excluded_docs' in params:
            query_params.append(('excluded_docs', params['excluded_docs']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/html'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikey']  # noqa: E501

        response_type='TopicRespModel'  # noqa: E501
        res = self.api_client.call_api(
            '/topics/topics', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

        #print('call-api res=', res)
        if res.job_id == None:
            pass
            #print('pass get_job.res=', res)
        else:
            #print('start polling...')
            i = 0
            job_id = res.job_id
            while res.result == None:
                time.sleep(1)
                res = self.get_job(job_id)
                #print('get_job.res=', res)
                if res.error != None:
                    print('Error:', res.error)
                    break

                i += 1
                if i > 7200:
                    print('Error: API timed out')
                    break
    
                if i % 60 == 0:
                    print('The job has been running for', i/60, 'minutes')
                #print('sleeping...', i)
            
            # poll completed. convert response to the actual API response type
            #print('response_type=', response_type)
            if response_type != 'JobRespModel':
                #print('res.result before poll', type(res.result), res.result)

                if isinstance(res.result, str):
                    result = res.result
                else:
                    result = res.result.to_str()
                     
                
                #print('res before conversion', result)
                res = self.api_client.deserialize_result(result, response_type)
                #print('res after conversion', type(res), res)

        return res


    def get_topic_delta_api(self, dataset, period_0_start, period_0_end, period_1_start, period_1_end, **kwargs):  # noqa: E501
        """get_topic_delta_api  # noqa: E501

        Get changes in exposure to key topics from documents in a dataset in between two dates.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_topic_delta_api(dataset, period_0_start, period_0_end, period_1_start, period_1_end, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset: Dataset with a time series component. These docs should reference a universe of entities that overlaps through time. (required)
        :param str period_0_start: Start date for the initial-period dataset. Format: \"YYYY-MM-DD HH:MM:SS\"  (required)
        :param str period_0_end: End date for the initial-period dataset. Format: \"YYYY-MM-DD HH:MM:SS\"  (required)
        :param str period_1_start: Start date for the final-period dataset. Format: \"YYYY-MM-DD HH:MM:SS\"  (required)
        :param str period_1_end: End date for the final-period dataset. Format: \"YYYY-MM-DD HH:MM:SS\"  (required)
        :param str query: Fulltext query, using mysql MATCH boolean query format. Example, (\"word1\" OR \"word2\") AND (\"word3\" OR \"word4\")
        :param str custom_stop_words: List of stop words.
        :param int num_topics: Number of topics to be extracted from the dataset.
        :param int num_keywords: Number of keywords per topic that is extracted from the dataset.
        :param str metadata_selection: json object of {\"metadata_field\":[\"selected_values\"]}
        :param str excluded_docs: List of document IDs that should be excluded from the analysis. Example, \"docid1, docid2, ..., docidN\" 
        :return: TopicDeltaRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_topic_delta_api_with_http_info(dataset, period_0_start, period_0_end, period_1_start, period_1_end, **kwargs)  # noqa: E501
        else:
            (data) = self.get_topic_delta_api_with_http_info(dataset, period_0_start, period_0_end, period_1_start, period_1_end, **kwargs)  # noqa: E501
            return data

    def get_topic_delta_api_with_http_info(self, dataset, period_0_start, period_0_end, period_1_start, period_1_end, **kwargs):  # noqa: E501
        """get_topic_delta_api  # noqa: E501

        Get changes in exposure to key topics from documents in a dataset in between two dates.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_topic_delta_api_with_http_info(dataset, period_0_start, period_0_end, period_1_start, period_1_end, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset: Dataset with a time series component. These docs should reference a universe of entities that overlaps through time. (required)
        :param str period_0_start: Start date for the initial-period dataset. Format: \"YYYY-MM-DD HH:MM:SS\"  (required)
        :param str period_0_end: End date for the initial-period dataset. Format: \"YYYY-MM-DD HH:MM:SS\"  (required)
        :param str period_1_start: Start date for the final-period dataset. Format: \"YYYY-MM-DD HH:MM:SS\"  (required)
        :param str period_1_end: End date for the final-period dataset. Format: \"YYYY-MM-DD HH:MM:SS\"  (required)
        :param str query: Fulltext query, using mysql MATCH boolean query format. Example, (\"word1\" OR \"word2\") AND (\"word3\" OR \"word4\")
        :param str custom_stop_words: List of stop words.
        :param int num_topics: Number of topics to be extracted from the dataset.
        :param int num_keywords: Number of keywords per topic that is extracted from the dataset.
        :param str metadata_selection: json object of {\"metadata_field\":[\"selected_values\"]}
        :param str excluded_docs: List of document IDs that should be excluded from the analysis. Example, \"docid1, docid2, ..., docidN\" 
        :return: TopicDeltaRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['dataset', 'period_0_start', 'period_0_end', 'period_1_start', 'period_1_end', 'query', 'custom_stop_words', 'num_topics', 'num_keywords', 'metadata_selection', 'excluded_docs']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_topic_delta_api" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'dataset' is set
        if ('dataset' not in params or
                params['dataset'] is None):
            raise ValueError("Missing the required parameter `dataset` when calling `get_topic_delta_api`")  # noqa: E501
        # verify the required parameter 'period_0_start' is set
        if ('period_0_start' not in params or
                params['period_0_start'] is None):
            raise ValueError("Missing the required parameter `period_0_start` when calling `get_topic_delta_api`")  # noqa: E501
        # verify the required parameter 'period_0_end' is set
        if ('period_0_end' not in params or
                params['period_0_end'] is None):
            raise ValueError("Missing the required parameter `period_0_end` when calling `get_topic_delta_api`")  # noqa: E501
        # verify the required parameter 'period_1_start' is set
        if ('period_1_start' not in params or
                params['period_1_start'] is None):
            raise ValueError("Missing the required parameter `period_1_start` when calling `get_topic_delta_api`")  # noqa: E501
        # verify the required parameter 'period_1_end' is set
        if ('period_1_end' not in params or
                params['period_1_end'] is None):
            raise ValueError("Missing the required parameter `period_1_end` when calling `get_topic_delta_api`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'dataset' in params:
            query_params.append(('dataset', params['dataset']))  # noqa: E501
        if 'query' in params:
            query_params.append(('query', params['query']))  # noqa: E501
        if 'custom_stop_words' in params:
            query_params.append(('custom_stop_words', params['custom_stop_words']))  # noqa: E501
        if 'num_topics' in params:
            query_params.append(('num_topics', params['num_topics']))  # noqa: E501
        if 'num_keywords' in params:
            query_params.append(('num_keywords', params['num_keywords']))  # noqa: E501
        if 'metadata_selection' in params:
            query_params.append(('metadata_selection', params['metadata_selection']))  # noqa: E501
        if 'period_0_start' in params:
            query_params.append(('period_0_start', params['period_0_start']))  # noqa: E501
        if 'period_0_end' in params:
            query_params.append(('period_0_end', params['period_0_end']))  # noqa: E501
        if 'period_1_start' in params:
            query_params.append(('period_1_start', params['period_1_start']))  # noqa: E501
        if 'period_1_end' in params:
            query_params.append(('period_1_end', params['period_1_end']))  # noqa: E501
        if 'excluded_docs' in params:
            query_params.append(('excluded_docs', params['excluded_docs']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/html'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikey']  # noqa: E501

        response_type='TopicDeltaRespModel'  # noqa: E501
        res = self.api_client.call_api(
            '/topics/topic_delta', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

        #print('call-api res=', res)
        if res.job_id == None:
            pass
            #print('pass get_job.res=', res)
        else:
            #print('start polling...')
            i = 0
            job_id = res.job_id
            while res.result == None:
                time.sleep(1)
                res = self.get_job(job_id)
                #print('get_job.res=', res)
                if res.error != None:
                    print('Error:', res.error)
                    break

                i += 1
                if i > 7200:
                    print('Error: API timed out')
                    break
    
                if i % 60 == 0:
                    print('The job has been running for', i/60, 'minutes')
                #print('sleeping...', i)
            
            # poll completed. convert response to the actual API response type
            #print('response_type=', response_type)
            if response_type != 'JobRespModel':
                #print('res.result before poll', type(res.result), res.result)

                if isinstance(res.result, str):
                    result = res.result
                else:
                    result = res.result.to_str()
                     
                
                #print('res before conversion', result)
                res = self.api_client.deserialize_result(result, response_type)
                #print('res after conversion', type(res), res)

        return res


    def get_topic_summary_api(self, dataset, **kwargs):  # noqa: E501
        """get_topic_summary_api  # noqa: E501

        Get summaries of topics that have been extracted from a dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_topic_summary_api(dataset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset: Dataset name. (required)
        :param str query: Fulltext query, using mysql MATCH boolean query format. Example, (\"word1\" OR \"word2\") AND (\"word3\" OR \"word4\")
        :param str custom_stop_words: List of stop words
        :param int num_topics: Number of topics to be extracted from the dataset and summarized.
        :param int num_keywords: Number of keywords per topic that is extracted from the dataset.
        :param str metadata_selection: json object of {\"metadata_field\":[\"selected_values\"]}
        :param str time_period: Alternative 1: Time period selection
        :param str period_start: Alternative 2: Start date for the period to analyze within the dataset. Format: \"YYYY-MM-DD HH:MM:SS\" 
        :param str period_end: Alternative 2: End date for the period to analyze within the dataset. Format: \"YYYY-MM-DD HH:MM:SS\" 
        :param int summary_length: The maximum number of bullet points a user wants to see in each topic summary.
        :param int context_amount: The number of sentences surrounding key summary sentences in the documents that they come from.
        :param int num_docs: The maximum number of key documents to use for summarization.
        :param str excluded_docs: List of document IDs that should be excluded from the analysis. Example, \"docid1, docid2, ..., docidN\" 
        :return: TopicSummaryRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_topic_summary_api_with_http_info(dataset, **kwargs)  # noqa: E501
        else:
            (data) = self.get_topic_summary_api_with_http_info(dataset, **kwargs)  # noqa: E501
            return data

    def get_topic_summary_api_with_http_info(self, dataset, **kwargs):  # noqa: E501
        """get_topic_summary_api  # noqa: E501

        Get summaries of topics that have been extracted from a dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_topic_summary_api_with_http_info(dataset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset: Dataset name. (required)
        :param str query: Fulltext query, using mysql MATCH boolean query format. Example, (\"word1\" OR \"word2\") AND (\"word3\" OR \"word4\")
        :param str custom_stop_words: List of stop words
        :param int num_topics: Number of topics to be extracted from the dataset and summarized.
        :param int num_keywords: Number of keywords per topic that is extracted from the dataset.
        :param str metadata_selection: json object of {\"metadata_field\":[\"selected_values\"]}
        :param str time_period: Alternative 1: Time period selection
        :param str period_start: Alternative 2: Start date for the period to analyze within the dataset. Format: \"YYYY-MM-DD HH:MM:SS\" 
        :param str period_end: Alternative 2: End date for the period to analyze within the dataset. Format: \"YYYY-MM-DD HH:MM:SS\" 
        :param int summary_length: The maximum number of bullet points a user wants to see in each topic summary.
        :param int context_amount: The number of sentences surrounding key summary sentences in the documents that they come from.
        :param int num_docs: The maximum number of key documents to use for summarization.
        :param str excluded_docs: List of document IDs that should be excluded from the analysis. Example, \"docid1, docid2, ..., docidN\" 
        :return: TopicSummaryRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['dataset', 'query', 'custom_stop_words', 'num_topics', 'num_keywords', 'metadata_selection', 'time_period', 'period_start', 'period_end', 'summary_length', 'context_amount', 'num_docs', 'excluded_docs']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_topic_summary_api" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'dataset' is set
        if ('dataset' not in params or
                params['dataset'] is None):
            raise ValueError("Missing the required parameter `dataset` when calling `get_topic_summary_api`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'dataset' in params:
            query_params.append(('dataset', params['dataset']))  # noqa: E501
        if 'query' in params:
            query_params.append(('query', params['query']))  # noqa: E501
        if 'custom_stop_words' in params:
            query_params.append(('custom_stop_words', params['custom_stop_words']))  # noqa: E501
        if 'num_topics' in params:
            query_params.append(('num_topics', params['num_topics']))  # noqa: E501
        if 'num_keywords' in params:
            query_params.append(('num_keywords', params['num_keywords']))  # noqa: E501
        if 'metadata_selection' in params:
            query_params.append(('metadata_selection', params['metadata_selection']))  # noqa: E501
        if 'time_period' in params:
            query_params.append(('time_period', params['time_period']))  # noqa: E501
        if 'period_start' in params:
            query_params.append(('period_start', params['period_start']))  # noqa: E501
        if 'period_end' in params:
            query_params.append(('period_end', params['period_end']))  # noqa: E501
        if 'summary_length' in params:
            query_params.append(('summary_length', params['summary_length']))  # noqa: E501
        if 'context_amount' in params:
            query_params.append(('context_amount', params['context_amount']))  # noqa: E501
        if 'num_docs' in params:
            query_params.append(('num_docs', params['num_docs']))  # noqa: E501
        if 'excluded_docs' in params:
            query_params.append(('excluded_docs', params['excluded_docs']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/html'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikey']  # noqa: E501

        response_type='TopicSummaryRespModel'  # noqa: E501
        res = self.api_client.call_api(
            '/topics/topic_summary', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

        #print('call-api res=', res)
        if res.job_id == None:
            pass
            #print('pass get_job.res=', res)
        else:
            #print('start polling...')
            i = 0
            job_id = res.job_id
            while res.result == None:
                time.sleep(1)
                res = self.get_job(job_id)
                #print('get_job.res=', res)
                if res.error != None:
                    print('Error:', res.error)
                    break

                i += 1
                if i > 7200:
                    print('Error: API timed out')
                    break
    
                if i % 60 == 0:
                    print('The job has been running for', i/60, 'minutes')
                #print('sleeping...', i)
            
            # poll completed. convert response to the actual API response type
            #print('response_type=', response_type)
            if response_type != 'JobRespModel':
                #print('res.result before poll', type(res.result), res.result)

                if isinstance(res.result, str):
                    result = res.result
                else:
                    result = res.result.to_str()
                     
                
                #print('res before conversion', result)
                res = self.api_client.deserialize_result(result, response_type)
                #print('res after conversion', type(res), res)

        return res


    def get_user(self, user_email, password, **kwargs):  # noqa: E501
        """get_user  # noqa: E501

        Use this API to authenticate. If the password is correct, returns the user details, including the user's api key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user(user_email, password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_email: Email of the user to authenticate.  (required)
        :param str password: Plaintext password of the user to authenticate.  (required)
        :return: UserModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_user_with_http_info(user_email, password, **kwargs)  # noqa: E501
        else:
            (data) = self.get_user_with_http_info(user_email, password, **kwargs)  # noqa: E501
            return data

    def get_user_with_http_info(self, user_email, password, **kwargs):  # noqa: E501
        """get_user  # noqa: E501

        Use this API to authenticate. If the password is correct, returns the user details, including the user's api key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_with_http_info(user_email, password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_email: Email of the user to authenticate.  (required)
        :param str password: Plaintext password of the user to authenticate.  (required)
        :return: UserModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_email', 'password']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_email' is set
        if ('user_email' not in params or
                params['user_email'] is None):
            raise ValueError("Missing the required parameter `user_email` when calling `get_user`")  # noqa: E501
        # verify the required parameter 'password' is set
        if ('password' not in params or
                params['password'] is None):
            raise ValueError("Missing the required parameter `password` when calling `get_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'user_email' in params:
            query_params.append(('user_email', params['user_email']))  # noqa: E501
        if 'password' in params:
            query_params.append(('password', params['password']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/html'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        response_type='UserModel'  # noqa: E501
        res = self.api_client.call_api(
            '/users', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

        #print('call-api res=', res)
        if res.job_id == None:
            pass
            #print('pass get_job.res=', res)
        else:
            #print('start polling...')
            i = 0
            job_id = res.job_id
            while res.result == None:
                time.sleep(1)
                res = self.get_job(job_id)
                #print('get_job.res=', res)
                if res.error != None:
                    print('Error:', res.error)
                    break

                i += 1
                if i > 7200:
                    print('Error: API timed out')
                    break
    
                if i % 60 == 0:
                    print('The job has been running for', i/60, 'minutes')
                #print('sleeping...', i)
            
            # poll completed. convert response to the actual API response type
            #print('response_type=', response_type)
            if response_type != 'JobRespModel':
                #print('res.result before poll', type(res.result), res.result)

                if isinstance(res.result, str):
                    result = res.result
                else:
                    result = res.result.to_str()
                     
                
                #print('res before conversion', result)
                res = self.api_client.deserialize_result(result, response_type)
                #print('res after conversion', type(res), res)

        return res


    def post_append_json_to_dataset(self, payload, **kwargs):  # noqa: E501
        """post_append_json_to_dataset  # noqa: E501

        Add a document to a dataset, in JSON form.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_append_json_to_dataset(payload, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Appendjsonparams payload: (required)
        :return: AppendJsonRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_append_json_to_dataset_with_http_info(payload, **kwargs)  # noqa: E501
        else:
            (data) = self.post_append_json_to_dataset_with_http_info(payload, **kwargs)  # noqa: E501
            return data

    def post_append_json_to_dataset_with_http_info(self, payload, **kwargs):  # noqa: E501
        """post_append_json_to_dataset  # noqa: E501

        Add a document to a dataset, in JSON form.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_append_json_to_dataset_with_http_info(payload, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Appendjsonparams payload: (required)
        :return: AppendJsonRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['payload']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_append_json_to_dataset" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'payload' is set
        if ('payload' not in params or
                params['payload'] is None):
            raise ValueError("Missing the required parameter `payload` when calling `post_append_json_to_dataset`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'payload' in params:
            body_params = params['payload']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikey']  # noqa: E501

        response_type='AppendJsonRespModel'  # noqa: E501
        res = self.api_client.call_api(
            '/datasets/append_json_to_dataset', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

        #print('call-api res=', res)
        if res.job_id == None:
            pass
            #print('pass get_job.res=', res)
        else:
            #print('start polling...')
            i = 0
            job_id = res.job_id
            while res.result == None:
                time.sleep(1)
                res = self.get_job(job_id)
                #print('get_job.res=', res)
                if res.error != None:
                    print('Error:', res.error)
                    break

                i += 1
                if i > 7200:
                    print('Error: API timed out')
                    break
    
                if i % 60 == 0:
                    print('The job has been running for', i/60, 'minutes')
                #print('sleeping...', i)
            
            # poll completed. convert response to the actual API response type
            #print('response_type=', response_type)
            if response_type != 'JobRespModel':
                #print('res.result before poll', type(res.result), res.result)

                if isinstance(res.result, str):
                    result = res.result
                else:
                    result = res.result.to_str()
                     
                
                #print('res before conversion', result)
                res = self.api_client.deserialize_result(result, response_type)
                #print('res after conversion', type(res), res)

        return res


    def post_delete_dataset(self, payload, **kwargs):  # noqa: E501
        """post_delete_dataset  # noqa: E501

        Delete an existing dataset from the user storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_delete_dataset(payload, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Deletedatasetmodel payload: (required)
        :return: DeleteDatasetRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_delete_dataset_with_http_info(payload, **kwargs)  # noqa: E501
        else:
            (data) = self.post_delete_dataset_with_http_info(payload, **kwargs)  # noqa: E501
            return data

    def post_delete_dataset_with_http_info(self, payload, **kwargs):  # noqa: E501
        """post_delete_dataset  # noqa: E501

        Delete an existing dataset from the user storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_delete_dataset_with_http_info(payload, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Deletedatasetmodel payload: (required)
        :return: DeleteDatasetRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['payload']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_delete_dataset" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'payload' is set
        if ('payload' not in params or
                params['payload'] is None):
            raise ValueError("Missing the required parameter `payload` when calling `post_delete_dataset`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'payload' in params:
            body_params = params['payload']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikey']  # noqa: E501

        response_type='DeleteDatasetRespModel'  # noqa: E501
        res = self.api_client.call_api(
            '/datasets/delete_dataset', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

        #print('call-api res=', res)
        if res.job_id == None:
            pass
            #print('pass get_job.res=', res)
        else:
            #print('start polling...')
            i = 0
            job_id = res.job_id
            while res.result == None:
                time.sleep(1)
                res = self.get_job(job_id)
                #print('get_job.res=', res)
                if res.error != None:
                    print('Error:', res.error)
                    break

                i += 1
                if i > 7200:
                    print('Error: API timed out')
                    break
    
                if i % 60 == 0:
                    print('The job has been running for', i/60, 'minutes')
                #print('sleeping...', i)
            
            # poll completed. convert response to the actual API response type
            #print('response_type=', response_type)
            if response_type != 'JobRespModel':
                #print('res.result before poll', type(res.result), res.result)

                if isinstance(res.result, str):
                    result = res.result
                else:
                    result = res.result.to_str()
                     
                
                #print('res before conversion', result)
                res = self.api_client.deserialize_result(result, response_type)
                #print('res after conversion', type(res), res)

        return res


    def post_delete_document(self, payload, **kwargs):  # noqa: E501
        """post_delete_document  # noqa: E501

        Delete a document from a dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_delete_document(payload, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Deletedocumentmodel payload: (required)
        :return: DeleteDocumentRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_delete_document_with_http_info(payload, **kwargs)  # noqa: E501
        else:
            (data) = self.post_delete_document_with_http_info(payload, **kwargs)  # noqa: E501
            return data

    def post_delete_document_with_http_info(self, payload, **kwargs):  # noqa: E501
        """post_delete_document  # noqa: E501

        Delete a document from a dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_delete_document_with_http_info(payload, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Deletedocumentmodel payload: (required)
        :return: DeleteDocumentRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['payload']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_delete_document" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'payload' is set
        if ('payload' not in params or
                params['payload'] is None):
            raise ValueError("Missing the required parameter `payload` when calling `post_delete_document`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'payload' in params:
            body_params = params['payload']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikey']  # noqa: E501

        response_type='DeleteDocumentRespModel'  # noqa: E501
        res = self.api_client.call_api(
            '/datasets/delete_document', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

        #print('call-api res=', res)
        if res.job_id == None:
            pass
            #print('pass get_job.res=', res)
        else:
            #print('start polling...')
            i = 0
            job_id = res.job_id
            while res.result == None:
                time.sleep(1)
                res = self.get_job(job_id)
                #print('get_job.res=', res)
                if res.error != None:
                    print('Error:', res.error)
                    break

                i += 1
                if i > 7200:
                    print('Error: API timed out')
                    break
    
                if i % 60 == 0:
                    print('The job has been running for', i/60, 'minutes')
                #print('sleeping...', i)
            
            # poll completed. convert response to the actual API response type
            #print('response_type=', response_type)
            if response_type != 'JobRespModel':
                #print('res.result before poll', type(res.result), res.result)

                if isinstance(res.result, str):
                    result = res.result
                else:
                    result = res.result.to_str()
                     
                
                #print('res before conversion', result)
                res = self.api_client.deserialize_result(result, response_type)
                #print('res after conversion', type(res), res)

        return res


    def post_example_job(self, color, wait_time, **kwargs):  # noqa: E501
        """post_example_job  # noqa: E501

        Start an example background job  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_example_job(color, wait_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str color: A color (required)
        :param int wait_time: Seconds to wait before returning the result (required)
        :return: ExampleJobResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_example_job_with_http_info(color, wait_time, **kwargs)  # noqa: E501
        else:
            (data) = self.post_example_job_with_http_info(color, wait_time, **kwargs)  # noqa: E501
            return data

    def post_example_job_with_http_info(self, color, wait_time, **kwargs):  # noqa: E501
        """post_example_job  # noqa: E501

        Start an example background job  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_example_job_with_http_info(color, wait_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str color: A color (required)
        :param int wait_time: Seconds to wait before returning the result (required)
        :return: ExampleJobResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['color', 'wait_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_example_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'color' is set
        if ('color' not in params or
                params['color'] is None):
            raise ValueError("Missing the required parameter `color` when calling `post_example_job`")  # noqa: E501
        # verify the required parameter 'wait_time' is set
        if ('wait_time' not in params or
                params['wait_time'] is None):
            raise ValueError("Missing the required parameter `wait_time` when calling `post_example_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'color' in params:
            query_params.append(('color', params['color']))  # noqa: E501
        if 'wait_time' in params:
            query_params.append(('wait_time', params['wait_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/html'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikey']  # noqa: E501

        response_type='ExampleJobResponse'  # noqa: E501
        res = self.api_client.call_api(
            '/jobs/start_example_job', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

        #print('call-api res=', res)
        if res.job_id == None:
            pass
            #print('pass get_job.res=', res)
        else:
            #print('start polling...')
            i = 0
            job_id = res.job_id
            while res.result == None:
                time.sleep(1)
                res = self.get_job(job_id)
                #print('get_job.res=', res)
                if res.error != None:
                    print('Error:', res.error)
                    break

                i += 1
                if i > 7200:
                    print('Error: API timed out')
                    break
    
                if i % 60 == 0:
                    print('The job has been running for', i/60, 'minutes')
                #print('sleeping...', i)
            
            # poll completed. convert response to the actual API response type
            #print('response_type=', response_type)
            if response_type != 'JobRespModel':
                #print('res.result before poll', type(res.result), res.result)

                if isinstance(res.result, str):
                    result = res.result
                else:
                    result = res.result.to_str()
                     
                
                #print('res before conversion', result)
                res = self.api_client.deserialize_result(result, response_type)
                #print('res after conversion', type(res), res)

        return res


    def post_legacy(self, payload, **kwargs):  # noqa: E501
        """post_legacy  # noqa: E501

        Recommendation of documents on given topics that have been extracted from a given dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_legacy(payload, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ApiCall payload: (required)
        :return: LegacyResponseModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_legacy_with_http_info(payload, **kwargs)  # noqa: E501
        else:
            (data) = self.post_legacy_with_http_info(payload, **kwargs)  # noqa: E501
            return data

    def post_legacy_with_http_info(self, payload, **kwargs):  # noqa: E501
        """post_legacy  # noqa: E501

        Recommendation of documents on given topics that have been extracted from a given dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_legacy_with_http_info(payload, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ApiCall payload: (required)
        :return: LegacyResponseModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['payload']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_legacy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'payload' is set
        if ('payload' not in params or
                params['payload'] is None):
            raise ValueError("Missing the required parameter `payload` when calling `post_legacy`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'payload' in params:
            body_params = params['payload']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikey']  # noqa: E501

        response_type='LegacyResponseModel'  # noqa: E501
        res = self.api_client.call_api(
            '/legacy', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

        #print('call-api res=', res)
        if res.job_id == None:
            pass
            #print('pass get_job.res=', res)
        else:
            #print('start polling...')
            i = 0
            job_id = res.job_id
            while res.result == None:
                time.sleep(1)
                res = self.get_job(job_id)
                #print('get_job.res=', res)
                if res.error != None:
                    print('Error:', res.error)
                    break

                i += 1
                if i > 7200:
                    print('Error: API timed out')
                    break
    
                if i % 60 == 0:
                    print('The job has been running for', i/60, 'minutes')
                #print('sleeping...', i)
            
            # poll completed. convert response to the actual API response type
            #print('response_type=', response_type)
            if response_type != 'JobRespModel':
                #print('res.result before poll', type(res.result), res.result)

                if isinstance(res.result, str):
                    result = res.result
                else:
                    result = res.result.to_str()
                     
                
                #print('res before conversion', result)
                res = self.api_client.deserialize_result(result, response_type)
                #print('res after conversion', type(res), res)

        return res


    def post_topic_consensus_api(self, dataset, **kwargs):  # noqa: E501
        """post_topic_consensus_api  # noqa: E501

        Get topic consensus for topics extracted from a given dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_topic_consensus_api(dataset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset: Dataset name. (required)
        :param str query: Fulltext query, using mysql MATCH boolean query format. Example, (\"word1\" OR \"word2\") AND (\"word3\" OR \"word4\")
        :param str custom_stop_words: List of stop words
        :param int num_topics: Number of topics to be extracted from the dataset.
        :param int num_keywords: Number of keywords per topic that is extracted from the dataset.
        :param str metadata_selection: json object of {\"metadata_field\":[\"selected_values\"]}
        :param str time_period: Alternative 1: Time period selection
        :param str period_start: Alternative 2: Start date for the period to analyze within the dataset. Format: \"YYYY-MM-DD HH:MM:SS\" 
        :param str period_end: Alternative 2: End date for the period to analyze within the dataset. Format: \"YYYY-MM-DD HH:MM:SS\" 
        :param str excluded_docs: List of document IDs that should be excluded from the analysis. Example, \"docid1, docid2, ..., docidN\" 
        :param file custom_dict_file: Custom sentiment dictionary JSON file.
        :return: TopicConsensusRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_topic_consensus_api_with_http_info(dataset, **kwargs)  # noqa: E501
        else:
            (data) = self.post_topic_consensus_api_with_http_info(dataset, **kwargs)  # noqa: E501
            return data

    def post_topic_consensus_api_with_http_info(self, dataset, **kwargs):  # noqa: E501
        """post_topic_consensus_api  # noqa: E501

        Get topic consensus for topics extracted from a given dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_topic_consensus_api_with_http_info(dataset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset: Dataset name. (required)
        :param str query: Fulltext query, using mysql MATCH boolean query format. Example, (\"word1\" OR \"word2\") AND (\"word3\" OR \"word4\")
        :param str custom_stop_words: List of stop words
        :param int num_topics: Number of topics to be extracted from the dataset.
        :param int num_keywords: Number of keywords per topic that is extracted from the dataset.
        :param str metadata_selection: json object of {\"metadata_field\":[\"selected_values\"]}
        :param str time_period: Alternative 1: Time period selection
        :param str period_start: Alternative 2: Start date for the period to analyze within the dataset. Format: \"YYYY-MM-DD HH:MM:SS\" 
        :param str period_end: Alternative 2: End date for the period to analyze within the dataset. Format: \"YYYY-MM-DD HH:MM:SS\" 
        :param str excluded_docs: List of document IDs that should be excluded from the analysis. Example, \"docid1, docid2, ..., docidN\" 
        :param file custom_dict_file: Custom sentiment dictionary JSON file.
        :return: TopicConsensusRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['dataset', 'query', 'custom_stop_words', 'num_topics', 'num_keywords', 'metadata_selection', 'time_period', 'period_start', 'period_end', 'excluded_docs', 'custom_dict_file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_topic_consensus_api" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'dataset' is set
        if ('dataset' not in params or
                params['dataset'] is None):
            raise ValueError("Missing the required parameter `dataset` when calling `post_topic_consensus_api`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'dataset' in params:
            query_params.append(('dataset', params['dataset']))  # noqa: E501
        if 'query' in params:
            query_params.append(('query', params['query']))  # noqa: E501
        if 'custom_stop_words' in params:
            query_params.append(('custom_stop_words', params['custom_stop_words']))  # noqa: E501
        if 'num_topics' in params:
            query_params.append(('num_topics', params['num_topics']))  # noqa: E501
        if 'num_keywords' in params:
            query_params.append(('num_keywords', params['num_keywords']))  # noqa: E501
        if 'metadata_selection' in params:
            query_params.append(('metadata_selection', params['metadata_selection']))  # noqa: E501
        if 'time_period' in params:
            query_params.append(('time_period', params['time_period']))  # noqa: E501
        if 'period_start' in params:
            query_params.append(('period_start', params['period_start']))  # noqa: E501
        if 'period_end' in params:
            query_params.append(('period_end', params['period_end']))  # noqa: E501
        if 'excluded_docs' in params:
            query_params.append(('excluded_docs', params['excluded_docs']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'custom_dict_file' in params:
            local_var_files['custom_dict_file'] = params['custom_dict_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikey']  # noqa: E501

        response_type='TopicConsensusRespModel'  # noqa: E501
        res = self.api_client.call_api(
            '/topics/topic_consensus', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

        #print('call-api res=', res)
        if res.job_id == None:
            pass
            #print('pass get_job.res=', res)
        else:
            #print('start polling...')
            i = 0
            job_id = res.job_id
            while res.result == None:
                time.sleep(1)
                res = self.get_job(job_id)
                #print('get_job.res=', res)
                if res.error != None:
                    print('Error:', res.error)
                    break

                i += 1
                if i > 7200:
                    print('Error: API timed out')
                    break
    
                if i % 60 == 0:
                    print('The job has been running for', i/60, 'minutes')
                #print('sleeping...', i)
            
            # poll completed. convert response to the actual API response type
            #print('response_type=', response_type)
            if response_type != 'JobRespModel':
                #print('res.result before poll', type(res.result), res.result)

                if isinstance(res.result, str):
                    result = res.result
                else:
                    result = res.result.to_str()
                     
                
                #print('res before conversion', result)
                res = self.api_client.deserialize_result(result, response_type)
                #print('res after conversion', type(res), res)

        return res


    def post_topic_historical_analysis_api(self, dataset, update_period, **kwargs):  # noqa: E501
        """post_topic_historical_analysis_api  # noqa: E501

        Get a historical analysis of topics extracted from a dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_topic_historical_analysis_api(dataset, update_period, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset: Dataset name. (required)
        :param str update_period: Frequency at which the historical anlaysis is performed (required)
        :param str query: Fulltext query, using mysql MATCH boolean query format. Example, (\"word1\" OR \"word2\") AND (\"word3\" OR \"word4\")
        :param str custom_stop_words: List of stop words
        :param int num_topics: Number of topics to be extracted from the dataset.
        :param int num_keywords: Number of keywords per topic that is extracted from the dataset.
        :param str metadata_selection: json object of {\"metadata_field\":[\"selected_values\"]}
        :param str time_period: Alternative 1: Time period selection
        :param str period_start: Alternative 2: Start date for the period to analyze within the dataset. Format: \"YYYY-MM-DD HH:MM:SS\" 
        :param str period_end: Alternative 2: End date for the period to analyze within the dataset. Format: \"YYYY-MM-DD HH:MM:SS\" 
        :param int inc_step: Number of increments of the udpate period in between two historical computations.
        :param str excluded_docs: List of document IDs that should be excluded from the analysis. Example, \"docid1, docid2, ..., docidN\" 
        :param file custom_dict_file: Custom sentiment dictionary JSON file.
        :return: TopicHistoryRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_topic_historical_analysis_api_with_http_info(dataset, update_period, **kwargs)  # noqa: E501
        else:
            (data) = self.post_topic_historical_analysis_api_with_http_info(dataset, update_period, **kwargs)  # noqa: E501
            return data

    def post_topic_historical_analysis_api_with_http_info(self, dataset, update_period, **kwargs):  # noqa: E501
        """post_topic_historical_analysis_api  # noqa: E501

        Get a historical analysis of topics extracted from a dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_topic_historical_analysis_api_with_http_info(dataset, update_period, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset: Dataset name. (required)
        :param str update_period: Frequency at which the historical anlaysis is performed (required)
        :param str query: Fulltext query, using mysql MATCH boolean query format. Example, (\"word1\" OR \"word2\") AND (\"word3\" OR \"word4\")
        :param str custom_stop_words: List of stop words
        :param int num_topics: Number of topics to be extracted from the dataset.
        :param int num_keywords: Number of keywords per topic that is extracted from the dataset.
        :param str metadata_selection: json object of {\"metadata_field\":[\"selected_values\"]}
        :param str time_period: Alternative 1: Time period selection
        :param str period_start: Alternative 2: Start date for the period to analyze within the dataset. Format: \"YYYY-MM-DD HH:MM:SS\" 
        :param str period_end: Alternative 2: End date for the period to analyze within the dataset. Format: \"YYYY-MM-DD HH:MM:SS\" 
        :param int inc_step: Number of increments of the udpate period in between two historical computations.
        :param str excluded_docs: List of document IDs that should be excluded from the analysis. Example, \"docid1, docid2, ..., docidN\" 
        :param file custom_dict_file: Custom sentiment dictionary JSON file.
        :return: TopicHistoryRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['dataset', 'update_period', 'query', 'custom_stop_words', 'num_topics', 'num_keywords', 'metadata_selection', 'time_period', 'period_start', 'period_end', 'inc_step', 'excluded_docs', 'custom_dict_file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_topic_historical_analysis_api" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'dataset' is set
        if ('dataset' not in params or
                params['dataset'] is None):
            raise ValueError("Missing the required parameter `dataset` when calling `post_topic_historical_analysis_api`")  # noqa: E501
        # verify the required parameter 'update_period' is set
        if ('update_period' not in params or
                params['update_period'] is None):
            raise ValueError("Missing the required parameter `update_period` when calling `post_topic_historical_analysis_api`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'dataset' in params:
            query_params.append(('dataset', params['dataset']))  # noqa: E501
        if 'query' in params:
            query_params.append(('query', params['query']))  # noqa: E501
        if 'custom_stop_words' in params:
            query_params.append(('custom_stop_words', params['custom_stop_words']))  # noqa: E501
        if 'num_topics' in params:
            query_params.append(('num_topics', params['num_topics']))  # noqa: E501
        if 'num_keywords' in params:
            query_params.append(('num_keywords', params['num_keywords']))  # noqa: E501
        if 'metadata_selection' in params:
            query_params.append(('metadata_selection', params['metadata_selection']))  # noqa: E501
        if 'time_period' in params:
            query_params.append(('time_period', params['time_period']))  # noqa: E501
        if 'period_start' in params:
            query_params.append(('period_start', params['period_start']))  # noqa: E501
        if 'period_end' in params:
            query_params.append(('period_end', params['period_end']))  # noqa: E501
        if 'update_period' in params:
            query_params.append(('update_period', params['update_period']))  # noqa: E501
        if 'inc_step' in params:
            query_params.append(('inc_step', params['inc_step']))  # noqa: E501
        if 'excluded_docs' in params:
            query_params.append(('excluded_docs', params['excluded_docs']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'custom_dict_file' in params:
            local_var_files['custom_dict_file'] = params['custom_dict_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikey']  # noqa: E501

        response_type='TopicHistoryRespModel'  # noqa: E501
        res = self.api_client.call_api(
            '/topics/topic_historical', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

        #print('call-api res=', res)
        if res.job_id == None:
            pass
            #print('pass get_job.res=', res)
        else:
            #print('start polling...')
            i = 0
            job_id = res.job_id
            while res.result == None:
                time.sleep(1)
                res = self.get_job(job_id)
                #print('get_job.res=', res)
                if res.error != None:
                    print('Error:', res.error)
                    break

                i += 1
                if i > 7200:
                    print('Error: API timed out')
                    break
    
                if i % 60 == 0:
                    print('The job has been running for', i/60, 'minutes')
                #print('sleeping...', i)
            
            # poll completed. convert response to the actual API response type
            #print('response_type=', response_type)
            if response_type != 'JobRespModel':
                #print('res.result before poll', type(res.result), res.result)

                if isinstance(res.result, str):
                    result = res.result
                else:
                    result = res.result.to_str()
                     
                
                #print('res before conversion', result)
                res = self.api_client.deserialize_result(result, response_type)
                #print('res after conversion', type(res), res)

        return res


    def post_topic_sentiment_api(self, dataset, **kwargs):  # noqa: E501
        """post_topic_sentiment_api  # noqa: E501

        Get topic sentiment for topics extracted from a given dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_topic_sentiment_api(dataset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset: Dataset name. (required)
        :param str query: Fulltext query, using mysql MATCH boolean query format. Example, (\"word1\" OR \"word2\") AND (\"word3\" OR \"word4\")
        :param str custom_stop_words: List of stop words
        :param int num_topics: Number of topics to be extracted from the dataset.
        :param int num_keywords: Number of keywords per topic that is extracted from the dataset.
        :param str metadata_selection: json object of {\"metadata_field\":[\"selected_values\"]}
        :param str time_period: Alternative 1: Time period selection
        :param str period_start: Alternative 2: Start date for the period to analyze within the dataset. Format: \"YYYY-MM-DD HH:MM:SS\" 
        :param str period_end: Alternative 2: End date for the period to analyze within the dataset. Format: \"YYYY-MM-DD HH:MM:SS\" 
        :param str excluded_docs: List of document IDs that should be excluded from the analysis. Example, \"docid1, docid2, ..., docidN\" 
        :param file custom_dict_file: Custom sentiment dictionary JSON file.
        :return: TopicSentimentRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_topic_sentiment_api_with_http_info(dataset, **kwargs)  # noqa: E501
        else:
            (data) = self.post_topic_sentiment_api_with_http_info(dataset, **kwargs)  # noqa: E501
            return data

    def post_topic_sentiment_api_with_http_info(self, dataset, **kwargs):  # noqa: E501
        """post_topic_sentiment_api  # noqa: E501

        Get topic sentiment for topics extracted from a given dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_topic_sentiment_api_with_http_info(dataset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str dataset: Dataset name. (required)
        :param str query: Fulltext query, using mysql MATCH boolean query format. Example, (\"word1\" OR \"word2\") AND (\"word3\" OR \"word4\")
        :param str custom_stop_words: List of stop words
        :param int num_topics: Number of topics to be extracted from the dataset.
        :param int num_keywords: Number of keywords per topic that is extracted from the dataset.
        :param str metadata_selection: json object of {\"metadata_field\":[\"selected_values\"]}
        :param str time_period: Alternative 1: Time period selection
        :param str period_start: Alternative 2: Start date for the period to analyze within the dataset. Format: \"YYYY-MM-DD HH:MM:SS\" 
        :param str period_end: Alternative 2: End date for the period to analyze within the dataset. Format: \"YYYY-MM-DD HH:MM:SS\" 
        :param str excluded_docs: List of document IDs that should be excluded from the analysis. Example, \"docid1, docid2, ..., docidN\" 
        :param file custom_dict_file: Custom sentiment dictionary JSON file.
        :return: TopicSentimentRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['dataset', 'query', 'custom_stop_words', 'num_topics', 'num_keywords', 'metadata_selection', 'time_period', 'period_start', 'period_end', 'excluded_docs', 'custom_dict_file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_topic_sentiment_api" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'dataset' is set
        if ('dataset' not in params or
                params['dataset'] is None):
            raise ValueError("Missing the required parameter `dataset` when calling `post_topic_sentiment_api`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'dataset' in params:
            query_params.append(('dataset', params['dataset']))  # noqa: E501
        if 'query' in params:
            query_params.append(('query', params['query']))  # noqa: E501
        if 'custom_stop_words' in params:
            query_params.append(('custom_stop_words', params['custom_stop_words']))  # noqa: E501
        if 'num_topics' in params:
            query_params.append(('num_topics', params['num_topics']))  # noqa: E501
        if 'num_keywords' in params:
            query_params.append(('num_keywords', params['num_keywords']))  # noqa: E501
        if 'metadata_selection' in params:
            query_params.append(('metadata_selection', params['metadata_selection']))  # noqa: E501
        if 'time_period' in params:
            query_params.append(('time_period', params['time_period']))  # noqa: E501
        if 'period_start' in params:
            query_params.append(('period_start', params['period_start']))  # noqa: E501
        if 'period_end' in params:
            query_params.append(('period_end', params['period_end']))  # noqa: E501
        if 'excluded_docs' in params:
            query_params.append(('excluded_docs', params['excluded_docs']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'custom_dict_file' in params:
            local_var_files['custom_dict_file'] = params['custom_dict_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikey']  # noqa: E501

        response_type='TopicSentimentRespModel'  # noqa: E501
        res = self.api_client.call_api(
            '/topics/topic_sentiment', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

        #print('call-api res=', res)
        if res.job_id == None:
            pass
            #print('pass get_job.res=', res)
        else:
            #print('start polling...')
            i = 0
            job_id = res.job_id
            while res.result == None:
                time.sleep(1)
                res = self.get_job(job_id)
                #print('get_job.res=', res)
                if res.error != None:
                    print('Error:', res.error)
                    break

                i += 1
                if i > 7200:
                    print('Error: API timed out')
                    break
    
                if i % 60 == 0:
                    print('The job has been running for', i/60, 'minutes')
                #print('sleeping...', i)
            
            # poll completed. convert response to the actual API response type
            #print('response_type=', response_type)
            if response_type != 'JobRespModel':
                #print('res.result before poll', type(res.result), res.result)

                if isinstance(res.result, str):
                    result = res.result
                else:
                    result = res.result.to_str()
                     
                
                #print('res before conversion', result)
                res = self.api_client.deserialize_result(result, response_type)
                #print('res after conversion', type(res), res)

        return res


    def post_upload_file(self, file, dataset, **kwargs):  # noqa: E501
        """post_upload_file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_upload_file(file, dataset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file file: (required)
        :param str dataset: Destination dataset where the file will be inserted. (required)
        :param str metadata: Optional json containing additional document metadata. Eg: {\"time\":\"01/01/2001\",\"author\":\"me\"}
        :return: UploadFileRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_upload_file_with_http_info(file, dataset, **kwargs)  # noqa: E501
        else:
            (data) = self.post_upload_file_with_http_info(file, dataset, **kwargs)  # noqa: E501
            return data

    def post_upload_file_with_http_info(self, file, dataset, **kwargs):  # noqa: E501
        """post_upload_file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_upload_file_with_http_info(file, dataset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file file: (required)
        :param str dataset: Destination dataset where the file will be inserted. (required)
        :param str metadata: Optional json containing additional document metadata. Eg: {\"time\":\"01/01/2001\",\"author\":\"me\"}
        :return: UploadFileRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file', 'dataset', 'metadata']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_upload_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file' is set
        if ('file' not in params or
                params['file'] is None):
            raise ValueError("Missing the required parameter `file` when calling `post_upload_file`")  # noqa: E501
        # verify the required parameter 'dataset' is set
        if ('dataset' not in params or
                params['dataset'] is None):
            raise ValueError("Missing the required parameter `dataset` when calling `post_upload_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'metadata' in params:
            query_params.append(('metadata', params['metadata']))  # noqa: E501
        if 'dataset' in params:
            query_params.append(('dataset', params['dataset']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'file' in params:
            local_var_files['file'] = params['file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikey']  # noqa: E501

        response_type='UploadFileRespModel'  # noqa: E501
        res = self.api_client.call_api(
            '/datasets/upload_file', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

        #print('call-api res=', res)
        if res.job_id == None:
            pass
            #print('pass get_job.res=', res)
        else:
            #print('start polling...')
            i = 0
            job_id = res.job_id
            while res.result == None:
                time.sleep(1)
                res = self.get_job(job_id)
                #print('get_job.res=', res)
                if res.error != None:
                    print('Error:', res.error)
                    break

                i += 1
                if i > 7200:
                    print('Error: API timed out')
                    break
    
                if i % 60 == 0:
                    print('The job has been running for', i/60, 'minutes')
                #print('sleeping...', i)
            
            # poll completed. convert response to the actual API response type
            #print('response_type=', response_type)
            if response_type != 'JobRespModel':
                #print('res.result before poll', type(res.result), res.result)

                if isinstance(res.result, str):
                    result = res.result
                else:
                    result = res.result.to_str()
                     
                
                #print('res before conversion', result)
                res = self.api_client.deserialize_result(result, response_type)
                #print('res after conversion', type(res), res)

        return res


    def post_upload_url(self, payload, **kwargs):  # noqa: E501
        """post_upload_url  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_upload_url(payload, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UploadURLModel payload: (required)
        :return: UploadUrlRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_upload_url_with_http_info(payload, **kwargs)  # noqa: E501
        else:
            (data) = self.post_upload_url_with_http_info(payload, **kwargs)  # noqa: E501
            return data

    def post_upload_url_with_http_info(self, payload, **kwargs):  # noqa: E501
        """post_upload_url  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_upload_url_with_http_info(payload, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UploadURLModel payload: (required)
        :return: UploadUrlRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['payload']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_upload_url" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'payload' is set
        if ('payload' not in params or
                params['payload'] is None):
            raise ValueError("Missing the required parameter `payload` when calling `post_upload_url`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'payload' in params:
            body_params = params['payload']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikey']  # noqa: E501

        response_type='UploadUrlRespModel'  # noqa: E501
        res = self.api_client.call_api(
            '/datasets/import_file_from_url', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

        #print('call-api res=', res)
        if res.job_id == None:
            pass
            #print('pass get_job.res=', res)
        else:
            #print('start polling...')
            i = 0
            job_id = res.job_id
            while res.result == None:
                time.sleep(1)
                res = self.get_job(job_id)
                #print('get_job.res=', res)
                if res.error != None:
                    print('Error:', res.error)
                    break

                i += 1
                if i > 7200:
                    print('Error: API timed out')
                    break
    
                if i % 60 == 0:
                    print('The job has been running for', i/60, 'minutes')
                #print('sleeping...', i)
            
            # poll completed. convert response to the actual API response type
            #print('response_type=', response_type)
            if response_type != 'JobRespModel':
                #print('res.result before poll', type(res.result), res.result)

                if isinstance(res.result, str):
                    result = res.result
                else:
                    result = res.result.to_str()
                     
                
                #print('res before conversion', result)
                res = self.api_client.deserialize_result(result, response_type)
                #print('res after conversion', type(res), res)

        return res


    def post_user(self, payload, **kwargs):  # noqa: E501
        """post_user  # noqa: E501

        Use this API to register a new user. Email and password are required, all other fields optional.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_user(payload, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param User payload: (required)
        :return: PostUserRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_user_with_http_info(payload, **kwargs)  # noqa: E501
        else:
            (data) = self.post_user_with_http_info(payload, **kwargs)  # noqa: E501
            return data

    def post_user_with_http_info(self, payload, **kwargs):  # noqa: E501
        """post_user  # noqa: E501

        Use this API to register a new user. Email and password are required, all other fields optional.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_user_with_http_info(payload, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param User payload: (required)
        :return: PostUserRespModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['payload']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'payload' is set
        if ('payload' not in params or
                params['payload'] is None):
            raise ValueError("Missing the required parameter `payload` when calling `post_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'payload' in params:
            body_params = params['payload']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikey']  # noqa: E501

        response_type='PostUserRespModel'  # noqa: E501
        res = self.api_client.call_api(
            '/users', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

        #print('call-api res=', res)
        if res.job_id == None:
            pass
            #print('pass get_job.res=', res)
        else:
            #print('start polling...')
            i = 0
            job_id = res.job_id
            while res.result == None:
                time.sleep(1)
                res = self.get_job(job_id)
                #print('get_job.res=', res)
                if res.error != None:
                    print('Error:', res.error)
                    break

                i += 1
                if i > 7200:
                    print('Error: API timed out')
                    break
    
                if i % 60 == 0:
                    print('The job has been running for', i/60, 'minutes')
                #print('sleeping...', i)
            
            # poll completed. convert response to the actual API response type
            #print('response_type=', response_type)
            if response_type != 'JobRespModel':
                #print('res.result before poll', type(res.result), res.result)

                if isinstance(res.result, str):
                    result = res.result
                else:
                    result = res.result.to_str()
                     
                
                #print('res before conversion', result)
                res = self.api_client.deserialize_result(result, response_type)
                #print('res after conversion', type(res), res)

        return res

